@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher;
 BEGIN {
-  $WWW::FetchStory::Fetcher::VERSION = '0.1301';
+  $WWW::FetchStory::Fetcher::VERSION = '0.1302';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1301
+version 0.1302
 
 =head1 DESCRIPTION
 
@@ -942,81 +942,80 @@ sub build_epub {
     $epub->add_source($info->{url}, 'URL');
     $epub->add_date($info->{fetched}, 'fetched');
 
-    # characters, universes
-    foreach my $key (qw(characters universe))
+    # Add Subjects and additional Meta
+    # Also build up the title-page
+    my $info_str =<<EOT;
+<h1>$info->{title}</h1>
+<p>by $info->{author}</p>
+<p><b>Fetched from:</b> $info->{url}</p>
+<p><b>Summary:</b> $info->{summary}</p>
+<p>
+EOT
+    my %know = %{$info};
+    delete $know{title};
+    delete $know{author};
+    delete $know{summary};
+    delete $know{url};
+    delete $know{fetched};
+    delete $know{basename};
+    delete $know{chapter_titles};
+    delete $know{chapter_wc};
+    delete $know{chapters};
+    delete $know{storyfiles};
+    foreach my $key (sort keys %know)
     {
-	if (exists $info->{$key} and $info->{$key})
+	if (!$know{$key})
 	{
-	    if ($info->{$key} =~ /,\s*/)
+	    next;
+	}
+	if (!ref $know{$key})
+	{
+	    $info_str .= sprintf("<b>%s:</b> %s<br/>\n", $key, $know{$key});
+	    if ($know{$key} =~ /,\s*/)
 	    {
-		my @array = split(/,\s*/, $info->{$key});
+		my @array = split(/,\s*/, $know{$key});
 		foreach my $v (@array)
 		{
-		    $epub->add_meta_item($key, $v);
+		    if ($key =~ /^(?:category|story_length)$/)
+		    {
+			$epub->add_subject($v);
+		    }
+		    else
+		    {
+			$epub->add_meta_item($key, $v);
+		    }
 		}
 	    }
-	    elsif (ref $info->{$key})
+	    else
 	    {
-		foreach my $v (@{$info->{$key}})
+		if ($key =~ /^(?:category|story_length)$/)
 		{
-		    $epub->add_meta_item($key, $v);
+		    $epub->add_subject($know{$key});
+		}
+		else
+		{
+		    $epub->add_meta_item($key, $know{$key});
 		}
 	    }
-	    else
+	}
+	else
+	{
+	    $info_str .= sprintf("<b>%s:</b> %s<br/>\n", $key, join(', ', @{$know{$key}}));
+	    foreach my $cat (@{$know{$key}})
 	    {
-		$epub->add_meta_item($key, $info->{$key});
+		if ($key =~ /^(?:category|story_length)$/)
+		{
+		    $epub->add_subject($cat);
+		}
+		else
+		{
+		    $epub->add_meta_item($key, $cat);
+		}
 	    }
 	}
     }
 
-    my @subjects = ();
-    foreach my $key (keys %{$info})
-    {
-	if (!($key eq 'title'
-		    or $key eq 'author'
-		    or $key eq 'summary'
-		    or $key eq 'url'
-		    or $key eq 'fetched'
-		    or $key eq 'wordcount'
-		    or $key eq 'basename'
-		    or $key eq 'characters'
-		    or $key eq 'universe'
-	    ) and !ref $info->{$key})
-	{
-	    my $label;
-	    if ($key =~ /^(?:category|story_length)$/)
-	    {
-		$label = '';
-	    }
-	    else
-	    {
-		$label = $key . ': ';
-	    }
-	    if ($info->{$key} =~ /, /)
-	    {
-		push @subjects, map { "${label}$_" } split(/, /, $info->{$key});
-	    }
-	    else
-	    {
-		push @subjects, $label . $info->{$key};
-	    }
-	}
-    }
-    foreach my $sub (@subjects)
-    {
-	$epub->add_subject($sub) if $sub;
-    }
-
-    my $info_str = "<h1>$info->{title}</h1>\n";
-    foreach my $key (sort keys %{$info})
-    {
-	next unless $info->{$key};
-	if (!($key =~ /(?:basename|title)/)
-	    and !ref $info->{$key})
-	{
-	    $info_str .= sprintf("<b>%s:</b> %s<br/>\n", $key, $info->{$key});
-	}
-    }
+    $info_str .= "</p>\n";
 
     my $titlepage = $self->tidy(story=>$info_str, title=>$info->{title});
     my $play_order = 1;
